==> servicecatalog-model-6.3.0-sources.jar: io/fabric8/servicecatalog/api/model/BasicAuthConfigFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BasicAuthConfigFluentImpl<A extends BasicAuthConfigFluent<A>> extends BaseFluent<A> implements BasicAuthConfigFluent<A>{
  public BasicAuthConfigFluentImpl() {
  }
  public BasicAuthConfigFluentImpl(BasicAuthConfig instance) {
    this.withSecretRef(instance.getSecretRef()); 
  }
  private LocalObjectReferenceBuilder secretRef;
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public LocalObjectReference buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  public BasicAuthConfigFluent.SecretRefNested<A> withNewSecretRef() {
    return new BasicAuthConfigFluentImpl.SecretRefNestedImpl();
  }
  public BasicAuthConfigFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item) {
    return new BasicAuthConfigFluentImpl.SecretRefNestedImpl(item);
  }
  public BasicAuthConfigFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public BasicAuthConfigFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new LocalObjectReferenceBuilder().build());
  }
  public BasicAuthConfigFluent.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BasicAuthConfigFluentImpl that = (BasicAuthConfigFluentImpl) o;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends LocalObjectReferenceFluentImpl<BasicAuthConfigFluent.SecretRefNested<N>> implements BasicAuthConfigFluent.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) BasicAuthConfigFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/BasicAuthConfigFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BasicAuthConfigFluentImpl<A extends BasicAuthConfigFluent<A>> extends BaseFluent<A> implements BasicAuthConfigFluent<A>{
  public BasicAuthConfigFluentImpl() {
  }
  public BasicAuthConfigFluentImpl(BasicAuthConfig instance) {
    if (instance != null) {
      this.withSecretRef(instance.getSecretRef());
    }
  }
  private LocalObjectReferenceBuilder secretRef;
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public LocalObjectReference buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  public BasicAuthConfigFluentImpl.SecretRefNested<A> withNewSecretRef() {
    return new BasicAuthConfigFluentImpl.SecretRefNestedImpl();
  }
  public BasicAuthConfigFluentImpl.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item) {
    return new BasicAuthConfigFluentImpl.SecretRefNestedImpl(item);
  }
  public BasicAuthConfigFluentImpl.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public BasicAuthConfigFluentImpl.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new LocalObjectReferenceBuilder().build());
  }
  public BasicAuthConfigFluentImpl.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BasicAuthConfigFluentImpl that = (BasicAuthConfigFluentImpl) o;
    if (!java.util.Objects.equals(secretRef, that.secretRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends LocalObjectReferenceFluentImpl<BasicAuthConfigFluentImpl.SecretRefNested<N>> implements BasicAuthConfigFluentImpl.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) BasicAuthConfigFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
